==> etpan-ng_0.5.orig.tar.gz: etpan-ng-0.5/src/etpan-cfg-global.h <==
/*
 * etPan! -- a mail user agent
 *
 * Copyright (C) 2001, 2002 - DINH Viet Hoa
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the libEtPan! project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * $Id: etpan-cfg-global.h,v 1.9 2004/11/14 19:17:13 hoa Exp $
 */

#ifndef ETPAN_CFG_GLOBAL_DECL_H

#define ETPAN_CFG_GLOBAL_DECL_H

#include "etpan-cfg-global-types.h"

int etpan_global_config_read(char * filename,
    struct etpan_global_config ** result);

struct etpan_global_config *
etpan_global_config_new(char * display_charset, char * editor_charset,
    char * message_charset, char * editor, int reply_quote_limit,
    int network_timeout, int poll_delay, char * sendmail_path,
    int thread_type, int across_folder);

void etpan_global_config_free(struct etpan_global_config * global_config);

int etpan_cfg_global_write(char * filename,
    struct etpan_global_config * global_config);

#endif

==> etpan-ng_0.6.1.orig.tar.gz: etpan-ng-0.6.1/src/etpan-cfg-global.h <==
/*
 * etPan! -- a mail user agent
 *
 * Copyright (C) 2001, 2002 - DINH Viet Hoa
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the libEtPan! project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * $Id: etpan-cfg-global.h,v 1.10 2005/02/06 23:48:56 hoa Exp $
 */

#ifndef ETPAN_CFG_GLOBAL_DECL_H

#define ETPAN_CFG_GLOBAL_DECL_H

#include "etpan-cfg-global-types.h"

int etpan_global_config_read(char * filename,
    struct etpan_global_config ** result);

struct etpan_global_config *
etpan_global_config_new(char * display_charset, char * editor_charset,
    char * message_charset, char * editor, int reply_quote_limit,
    int network_timeout, int poll_delay, char * sendmail_path,
    int thread_type, int across_folder, int ui_style,
    int folderlist_width, int msglist_height);

void etpan_global_config_free(struct etpan_global_config * global_config);

int etpan_cfg_global_write(char * filename,
    struct etpan_global_config * global_config);

#endif
